/** @format */

import React from "react";
import videojs from "video.js";
import seekButtons from "videojs-seek-buttons";
import "videojs-seek-buttons/dist/videojs-seek-buttons.css";
import hlsQualitySelector from "videojs-hls-quality-selector";
import qualityLevels from "videojs-contrib-quality-levels";
import "videojs-hotkeys";

 class VideoPlayer extends React.Component {
  componentDidMount() {
    videojs.registerPlugin("seekButtons", seekButtons);
    videojs.registerPlugin("qualityLevels", qualityLevels);
    videojs.registerPlugin("hlsQualitySelector", hlsQualitySelector);

    // instantiate Video.js
    this.player = videojs(this.videoNode, this.props, function onPlayerReady() {
      console.log("onPlayerReady", this);
    });
    this.player.hlsQualitySelector({ displayCurrentQuality: true });

    this.player.on("keydown", (e) => {
      const playerVolume = this.player.volume();
      const playerCurrentTime = this.player.currentTime();
      switch (e.code) {
        case "ArrowRight":
          this.player.currentTime(playerCurrentTime + 10);
          break;
        case "ArrowLeft":
          this.player.currentTime(playerCurrentTime - 10);
          break;
        case "ArrowUp":
          this.player.volume(playerVolume + 0.1);
          break;
        case "ArrowDown":
          this.player.volume(playerVolume - 0.1);
          break;
        case "KeyM":
          this.player.volume();
          break;
        default:
          return;
      }
    });
  }

  // destroy player on unmount
  componentWillUnmount() {
    if (this.player) {
      this.player.dispose();
    }
  }

  // wrap the player in a div with a `data-vjs-player` attribute
  // so videojs won't create additional wrapper in the DOM
  // see https://github.com/videojs/video.js/pull/3856
  render() {
    return (
      <div>
        <div data-vjs-player>
          <video ref={(node) => (this.videoNode = node)} className='video-js' />
        </div>
      </div>
    )
  }
}
export default VideoPlayer;